(function (exports) {
'use strict';

var ClassList = function () {
  function ClassList(component) {
    var tokens = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : [];
    babelHelpers.classCallCheck(this, ClassList);

    this.component = component;
    this.tokens = tokens;
  }

  babelHelpers.createClass(ClassList, [{
    key: 'add',
    value: function add(token) {
      if (this.contains(token)) return;
      this.tokens.push(token);
    }
  }, {
    key: 'contains',
    value: function contains(token) {
      return this.tokens.indexOf(token) !== -1;
    }
  }, {
    key: 'item',
    value: function item(index) {
      return this.tokens[index] || null;
    }
  }, {
    key: 'remove',
    value: function remove(token) {
      var i = this.tokens.indexOf(token);
      if (i === -1) return;
      this.tokens.splice(i, 1);
    }
  }, {
    key: 'toggle',
    value: function toggle(token) {
      if (this.contains(token)) {
        this.remove(token);
      } else {
        this.add(token);
      }
    }
  }, {
    key: 'update',
    value: function update(tokenMap) {
      for (var token in tokenMap) {
        if (tokenMap[token]) {
          this.add(token);
        } else {
          this.remove(token);
        }
      }

      var className = this.toString();
      if (className != this.component.state.className) this.component.setState({ className: className });
    }
  }, {
    key: 'toString',
    value: function toString() {
      return this.tokens.join(' ');
    }
  }]);
  return ClassList;
}();

var Component = function (_React$Component) {
  babelHelpers.inherits(Component, _React$Component);

  function Component(props, context) {
    babelHelpers.classCallCheck(this, Component);

    var _this = babelHelpers.possibleConstructorReturn(this, (Component.__proto__ || Object.getPrototypeOf(Component)).call(this, props, context));

    _this.state = {
      l10n: _this.player.l10n
    };
    _this.classList = new ClassList(_this, _this.props.classList);
    return _this;
  }

  babelHelpers.createClass(Component, [{
    key: "onlanguagechange",
    value: function onlanguagechange() {
      this.setState({ l10n: this.player.l10n });
    }
  }, {
    key: "shouldComponentUpdate",
    value: function shouldComponentUpdate(nextProps, nextState) {
      var state = this.state;
      var props = this.props;

      if (nextState != null) {
        for (var key in nextState) {
          if (nextState[key] != state[key]) {
            return true;
          }
        }
      }

      // TODO: Is this needed?
      if (nextProps != null) {
        for (var _key in nextProps) {
          if (nextProps[_key] != props[_key]) {
            return true;
          }
        }
      }

      return false;
    }
  }, {
    key: "componentWillMount",
    value: function componentWillMount() {
      var _this2 = this;

      this.playerEventMap.forEach(function (event) {
        _this2[event.key] = _this2[event.key].bind(_this2);
        _this2.player.addEventListener(event.type, _this2[event.key]);
      });
    }
  }, {
    key: "componentWillUnmount",
    value: function componentWillUnmount() {
      var _this3 = this;

      this.playerEventMap.forEach(function (event) {
        _this3.player.removeEventListener(event.type, _this3[event.key]);
      });
    }
  }, {
    key: "render",
    value: function render() {
      return React.createElement(
        "div",
        babelHelpers.extends({ ref: "element" }, this.propsList),
        this.textContent,
        this.children
      );
    }
  }, {
    key: "player",
    get: function get() {
      return this.props.player || this.context.player;
    }
  }, {
    key: "config",
    get: function get() {
      return this.props.config || this.context.config;
    }
  }, {
    key: "plugin",
    get: function get() {
      return this.context.plugin;
    }
  }, {
    key: "className",
    get: function get() {
      var className = this.props.className || "";
      className += " " + this.classList;

      return className.trim();
    }
  }, {
    key: "textContent",
    get: function get() {
      return this.props.textContent || this.state.textContent;
    }
  }, {
    key: "children",
    get: function get() {
      return this.props.children;
    }
  }, {
    key: "element",
    get: function get() {
      return this.refs.element;
    }
  }, {
    key: "playerEventMap",
    get: function get() {
      var _this4 = this;

      var events = [];

      if (this.player == null) return events;

      akamai.amp.Events.values.forEach(function (type) {
        var key = "on" + type;
        if (typeof _this4[key] != "function") return;
        events.push({ key: key, type: type });
      });

      return events;
    }
  }, {
    key: "propsList",
    get: function get() {
      var _props = this.props,
          className = _props.className,
          classList = _props.classList,
          textContent = _props.textContent,
          props = babelHelpers.objectWithoutProperties(_props, ["className", "classList", "textContent"]);

      props.className = this.className;
      return props;
    }
  }, {
    key: "l10n",
    get: function get() {
      return this.state.l10n;
    }
  }], [{
    key: "contextTypes",
    get: function get() {
      return {
        player: React.PropTypes.object,
        config: React.PropTypes.object,
        plugin: React.PropTypes.object
      };
    }
  }]);
  return Component;
}(React.Component);

var Container = function (_Component) {
  babelHelpers.inherits(Container, _Component);

  function Container(props, context) {
    babelHelpers.classCallCheck(this, Container);

    var _this = babelHelpers.possibleConstructorReturn(this, (Container.__proto__ || Object.getPrototypeOf(Container)).call(this, props, context));

    _this.state.components = [];
    return _this;
  }

  babelHelpers.createClass(Container, [{
    key: "addComponent",
    value: function addComponent(component) {
      var components = this.state.components.slice();
      components.push(component);
      this.setState({ components: components });
    }
  }, {
    key: "removeComponent",
    value: function removeComponent(component) {
      var components = this.state.components.filter(function (item) {
        return item != component;
      });
      this.setState({ components: components });
    }
  }, {
    key: "render",
    value: function render() {
      return React.createElement(
        "div",
        babelHelpers.extends({ ref: "element" }, this.propsList, { className: this.className }),
        this.props.children,
        this.state.components
      );
    }
  }]);
  return Container;
}(Component);

var Control = function (_Component) {
  babelHelpers.inherits(Control, _Component);

  function Control(props, context) {
    babelHelpers.classCallCheck(this, Control);

    var _this = babelHelpers.possibleConstructorReturn(this, (Control.__proto__ || Object.getPrototypeOf(Control)).call(this, props, context));

    _this.classList.add("amp-icon");
    _this.classList.add("amp-control");
    _this.mouseFocus = false;
    _this.state.altText = _this.altText;

    _this.onMouseDown = _this.onMouseDown.bind(_this);
    _this.onMouseUp = _this.onMouseUp.bind(_this);
    _this.onFocus = _this.onFocus.bind(_this);
    _this.onBlur = _this.onBlur.bind(_this);
    _this.onKeyDown = _this.onKeyDown.bind(_this);
    _this.onClick = _this.onClick.bind(_this);

    if (_this.onChange) _this.onChange = _this.onChange.bind(_this);
    return _this;
  }

  babelHelpers.createClass(Control, [{
    key: "onMouseDown",
    value: function onMouseDown(event) {
      this.mouseFocus = true;
    }
  }, {
    key: "onMouseUp",
    value: function onMouseUp(event) {
      this.mouseFocus = false;
    }
  }, {
    key: "onFocus",
    value: function onFocus(event) {
      if (this.mouseFocus == true) return;

      this.classList.update({ "amp-focus": true });
    }
  }, {
    key: "onBlur",
    value: function onBlur(event) {
      if (this.mouseFocus == true) return;

      this.classList.update({ "amp-focus": false });
    }
  }, {
    key: "onKeyDown",
    value: function onKeyDown(event) {
      if (this.mouseFocus == true) return;

      this.onKeyPress(event);

      if (event.type == "keypress" && (event.keyCode == 13 || event.keyCode == 32)) this.onAction();
    }
  }, {
    key: "onAction",
    value: function onAction() {
      this.onClick();
    }
  }, {
    key: "onKeyPress",
    value: function onKeyPress(event) {}
  }, {
    key: "onClick",
    value: function onClick(event) {}
  }, {
    key: "change",
    value: function change(value) {
      var onChange = this.propsList.onChange || this.onChange;
      if (typeof onChange != "function") return;
      onChange(value);
    }
  }, {
    key: "render",
    value: function render() {
      return React.createElement(
        "button",
        babelHelpers.extends({ ref: "element" }, this.propsList),
        this.textContent,
        this.children
      );
    }
  }, {
    key: "propsList",
    get: function get() {
      var _this2 = this;

      var _babelHelpers$get = babelHelpers.get(Control.prototype.__proto__ || Object.getPrototypeOf(Control.prototype), "propsList", this),
          altText = _babelHelpers$get.altText,
          props = babelHelpers.objectWithoutProperties(_babelHelpers$get, ["altText"]);

      props.className = this.className;
      props.tabIndex = "0";
      props["aria-label"] = this.title;
      props.onMouseDown = function (event) {
        return (_this2.props.onMouseDown || _this2.onMouseDown)(event);
      };
      props.onMouseUp = function (event) {
        return (_this2.props.onMouseUp || _this2.onMouseUp)(event);
      };
      props.onFocus = function (event) {
        return (_this2.props.onFocus || _this2.onFocus)(event);
      };
      props.onBlur = function (event) {
        return (_this2.props.onBlur || _this2.onBlur)(event);
      };
      props.onKeyDown = function (event) {
        return (_this2.props.onKeyDown || _this2.onKeyDown)(event);
      };
      props.onClick = function (event) {
        return (_this2.props.onClick || _this2.onClick)(event);
      };
      return props;
    }
  }, {
    key: "altText",
    get: function get() {
      return this.props.altText || this.state.altText;
    }
  }, {
    key: "title",
    get: function get() {
      return this.player.l10n[this.altText];
    }
  }]);
  return Control;
}(Component);

var PanelControl = function (_Control) {
  babelHelpers.inherits(PanelControl, _Control);

  function PanelControl(props, context) {
    babelHelpers.classCallCheck(this, PanelControl);
    return babelHelpers.possibleConstructorReturn(this, (PanelControl.__proto__ || Object.getPrototypeOf(PanelControl)).call(this, props, context));
  }

  return PanelControl;
}(Control);

var PlayPause = function (_Control) {
  babelHelpers.inherits(PlayPause, _Control);

  function PlayPause(props, context) {
    babelHelpers.classCallCheck(this, PlayPause);

    var _this = babelHelpers.possibleConstructorReturn(this, (PlayPause.__proto__ || Object.getPrototypeOf(PlayPause)).call(this, props, context));

    _this.classList.add("amp-playpause");
    _this.state.altText = "MSG_PLAY";
    return _this;
  }

  babelHelpers.createClass(PlayPause, [{
    key: "onplaying",
    value: function onplaying() {
      this.setState({ altText: "MSG_PAUSE" });
    }
  }, {
    key: "onpause",
    value: function onpause() {
      this.setState({ altText: "MSG_PLAY" });
    }
  }, {
    key: "onended",
    value: function onended() {
      this.setState({ altText: "MSG_REPLAY" });
    }
  }, {
    key: "onClick",
    value: function onClick() {
      var player = this.player;
      switch (player.playState) {
        case "ended":
          this.plugin.replay();
          break;

        case "ready":
        case "paused":
          player.play();
          break;

        default:
          player.pause();
          break;
      }
    }
  }]);
  return PlayPause;
}(Control);

var PauseOverlay = function (_Control) {
  babelHelpers.inherits(PauseOverlay, _Control);

  function PauseOverlay(props, context) {
    babelHelpers.classCallCheck(this, PauseOverlay);

    var _this = babelHelpers.possibleConstructorReturn(this, (PauseOverlay.__proto__ || Object.getPrototypeOf(PauseOverlay)).call(this, props, context));

    _this.classList.add("amp-pause-overlay");
    _this.state.altText = "MSG_PLAY";
    return _this;
  }

  babelHelpers.createClass(PauseOverlay, [{
    key: "onClick",
    value: function onClick() {
      var player = this.player;
      switch (player.playState) {
        case "ended":
          this.plugin.replay();
          break;

        default:
          player.play();
          break;
      }
    }
  }]);
  return PauseOverlay;
}(Control);

var BufferingOverlay = function (_Component) {
  babelHelpers.inherits(BufferingOverlay, _Component);

  function BufferingOverlay(props, context) {
    babelHelpers.classCallCheck(this, BufferingOverlay);

    var _this = babelHelpers.possibleConstructorReturn(this, (BufferingOverlay.__proto__ || Object.getPrototypeOf(BufferingOverlay)).call(this, props, context));

    _this.classList.add("amp-buffering-overlay");
    return _this;
  }

  return BufferingOverlay;
}(Component);

var Rewind = function (_Control) {
  babelHelpers.inherits(Rewind, _Control);

  function Rewind(props, context) {
    babelHelpers.classCallCheck(this, Rewind);

    var _this = babelHelpers.possibleConstructorReturn(this, (Rewind.__proto__ || Object.getPrototypeOf(Rewind)).call(this, props, context));

    _this.classList.add("amp-rewind");
    return _this;
  }

  babelHelpers.createClass(Rewind, [{
    key: "onClick",
    value: function onClick() {
      this.player.currentTime = Math.max(this.player.currentTime - 15, 0);
    }
  }]);
  return Rewind;
}(Control);

var Utils = function () {
  function Utils() {
    babelHelpers.classCallCheck(this, Utils);
  }

  babelHelpers.createClass(Utils, null, [{
    key: "formatTimecode",


    /**
     * Takes a time in seconds and converts it to timecode.
     * 
     * @param   {Number}  time  The time in seconds to be formatted.
     * @return  {String}  A SMTP formatted string.
     */
    value: function formatTimecode(time, duration) {
      time = parseInt(time);
      if (isNaN(time)) {
        return "00:00";
      }
      var strTime = Utils.formatZeroFill(time % 60);
      time = parseInt(time / 60);
      strTime = Utils.formatZeroFill(time % 60) + ":" + strTime;
      time = parseInt(time / 60);
      if (time > 0) {
        strTime = Utils.formatZeroFill(time) + ":" + strTime;
      }
      if (duration >= 3600 && strTime.length === 5) {
        strTime = "00:" + strTime;
      }
      return strTime;
    }

    /**
     * Converts a time in seconds to a string and adds a zero in front of any number lower than 10.
     * 
     * @param {Number} time The number to be zero filled.
     */

  }, {
    key: "formatZeroFill",
    value: function formatZeroFill(time) {
      var str = time.toString();
      if (time < 10) {
        str = "0" + str;
      }
      return str;
    }

    /**
     * @param {Number} number 
     *    The number to be rounded.
     *
     * @param {Number} precision 
     *    The level of precision. Positive 1 would round to 1 decimal place and -1 would round to the tens.
     *
     * @return {Number}
     *    The rounded number.
     */

  }, {
    key: "round",
    value: function round(number, precision) {
      var factor = Math.pow(10, precision);
      return Math.round(number * factor) / factor;
    }
  }, {
    key: "getElementOffset",
    value: function getElementOffset(element) {
      var root = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : document.fullscreenElement || document.webkitFullscreenElement || document.mozFullscreenElement;

      var left = 0;
      var top = 0;
      var width = element.offsetWidth;
      var height = element.offsetHeight;
      var scrollLeft = 0;
      var scrollTop = 0;

      while (element && element !== root) {
        if (element.tagName === "BODY") {
          scrollLeft = element.scrollLeft || document.documentElement.scrollLeft;
          scrollTop = element.scrollTop || document.documentElement.scrollTop;
          left += element.offsetLeft - scrollLeft + element.clientLeft;
          top += element.offsetTop - scrollTop + element.clientTop;
        } else {
          left += element.offsetLeft - element.scrollLeft + element.clientLeft;
          top += element.offsetTop - element.scrollTop + element.clientTop;
        }
        element = element.offsetParent;
      }

      return { left: left, top: top, width: width, height: height };
    }
  }, {
    key: "getEventPos",
    value: function getEventPos(event) {
      return {
        x: event.clientX || event.targetTouches[0].clientX,
        y: event.clientY || event.targetTouches[0].clientY
      };
    }
  }]);
  return Utils;
}();

var CurrentTime = function (_Component) {
  babelHelpers.inherits(CurrentTime, _Component);

  function CurrentTime(props, context) {
    babelHelpers.classCallCheck(this, CurrentTime);

    var _this = babelHelpers.possibleConstructorReturn(this, (CurrentTime.__proto__ || Object.getPrototypeOf(CurrentTime)).call(this, props, context));

    _this.state.currentTime = _this.player.currentTime;
    _this.state.duration = _this.player.duration;
    return _this;
  }

  babelHelpers.createClass(CurrentTime, [{
    key: "ontimeupdate",
    value: function ontimeupdate(event) {
      this.setState({ currentTime: Math.round(event.detail) });
    }
  }, {
    key: "ondurationchange",
    value: function ondurationchange(event) {
      this.setState({ duration: Math.round(event.detail) });
    }
  }, {
    key: "render",
    value: function render() {
      return React.createElement(
        "span",
        { className: "amp-current-time" },
        Utils.formatTimecode(this.state.currentTime, this.state.duration)
      );
    }
  }]);
  return CurrentTime;
}(Component);

var Duration = function (_Component) {
  babelHelpers.inherits(Duration, _Component);

  function Duration(props, context) {
    babelHelpers.classCallCheck(this, Duration);

    var _this = babelHelpers.possibleConstructorReturn(this, (Duration.__proto__ || Object.getPrototypeOf(Duration)).call(this, props, context));

    _this.state.duration = _this.player.duration;
    return _this;
  }

  babelHelpers.createClass(Duration, [{
    key: "ondurationchange",
    value: function ondurationchange(event) {
      this.setState({ duration: Math.round(event.detail) });
    }
  }, {
    key: "render",
    value: function render() {
      return React.createElement(
        "span",
        { className: "amp-duration" },
        Utils.formatTimecode(this.state.duration, this.state.duration)
      );
    }
  }]);
  return Duration;
}(Component);

var Slider = function (_Control) {
  babelHelpers.inherits(Slider, _Control);

  function Slider(props, context) {
    babelHelpers.classCallCheck(this, Slider);

    var _this = babelHelpers.possibleConstructorReturn(this, (Slider.__proto__ || Object.getPrototypeOf(Slider)).call(this, props, context));

    _this.state.percent = 0;
    _this.state.value = 0;
    _this.state.displayValue = 0;
    _this.state.min = 0;
    _this.state.max = 1;
    _this.increment = 0.1;
    _this.classList.add("amp-slider");
    return _this;
  }

  babelHelpers.createClass(Slider, [{
    key: "format",
    value: function format(value) {
      return value;
    }
  }, {
    key: "update",
    value: function update(values) {
      if (values.percent == null) values.percent = values.value / this.max;

      if (values.value == null) values.value = Math.round(values.percent * this.max);

      if (values.valueText == null) values.valueText = this.format(values.value) + " " + this.player.l10n["MSG_OF"] + " " + this.format(this.max);

      this.setState(values);
      return values;
    }
  }, {
    key: "onClick",
    value: function onClick(event) {
      var offset = Utils.getElementOffset(this.refs.element);
      var pos = Utils.getEventPos(event);
      this.percent = (pos.x - offset.left) / offset.width;
    }
  }, {
    key: "onAction",
    value: function onAction() {}
  }, {
    key: "onKeyPress",
    value: function onKeyPress(event) {
      var code = event.keyCode;
      // left arrow	37
      // up arrow	38
      // right arrow	39
      // down arrow	40
      if (code == 39 || code == 38) {
        this.percent += this.increment;
      } else if (code == 37 || code == 40) {
        this.percent -= this.increment;
      }
    }
  }, {
    key: "render",
    value: function render() {
      var percent = Utils.round(this.percent * 100, 2) + "%";
      return React.createElement(
        "div",
        babelHelpers.extends({ ref: "element" }, this.propsList),
        React.createElement("div", { className: "amp-value", style: { width: percent } }),
        React.createElement("div", { className: "amp-handle", style: { left: percent } }),
        React.createElement(Container, { ref: "markers", className: "amp-markers" }),
        React.createElement(
          "div",
          { className: "amp-text", style: { left: percent } },
          this.format(this.state.value)
        )
      );
    }
  }, {
    key: "percent",
    set: function set(value) {
      // TODO: Replace with akamai.amp.Utils.clamp
      value = akamai.amp.utils.Utils.clamp(value, 0, 1);

      if (this.percent == value) return;

      this.change(this.update({ percent: value }));
    },
    get: function get() {
      return this.state.percent;
    }
  }, {
    key: "value",
    set: function set(value) {
      // TODO: Replace with akamai.amp.Utils.clamp
      value = akamai.amp.utils.Utils.clamp(value, this.min, this.max);

      if (this.value == value) return;

      this.change(this.update({ value: value }));
    },
    get: function get() {
      return this.state.value;
    }
  }, {
    key: "min",
    set: function set(value) {
      if (this.min == value) return;

      this.setState({ min: value });
    },
    get: function get() {
      return this.state.min;
    }
  }, {
    key: "max",
    set: function set(value) {
      if (this.max == value) return;

      this.setState({ max: value });
    },
    get: function get() {
      return this.state.max;
    }
  }, {
    key: "markers",
    get: function get() {
      return this.refs.markers;
    }
  }, {
    key: "propsList",
    get: function get() {
      var _babelHelpers$get = babelHelpers.get(Slider.prototype.__proto__ || Object.getPrototypeOf(Slider.prototype), "propsList", this),
          altText = _babelHelpers$get.altText,
          props = babelHelpers.objectWithoutProperties(_babelHelpers$get, ["altText"]);

      props.role = "slider";
      props["aria-valuemin"] = this.state.min;
      props["aria-valuemax"] = Math.round(this.state.max);
      props["aria-valuenow"] = Math.round(this.state.value);
      props["aria-valuetext"] = this.state.valueText;
      return props;
    }
  }]);
  return Slider;
}(Control);

var Progress = function (_Slider) {
  babelHelpers.inherits(Progress, _Slider);

  function Progress(props, context) {
    babelHelpers.classCallCheck(this, Progress);

    var _this = babelHelpers.possibleConstructorReturn(this, (Progress.__proto__ || Object.getPrototypeOf(Progress)).call(this, props, context));

    _this.classList.add("amp-progress");
    _this.state.altText = "MSG_SEEK";
    return _this;
  }

  babelHelpers.createClass(Progress, [{
    key: "format",
    value: function format(value) {
      return Utils.formatTimecode(value, this.max);
    }
  }, {
    key: "onmediachange",
    value: function onmediachange() {
      this.update({ value: 0 });
    }
  }, {
    key: "ontimeupdate",
    value: function ontimeupdate() {
      this.update({ value: this.player.currentTime });
    }
  }, {
    key: "ondurationchange",
    value: function ondurationchange() {
      this.increment = 10 / this.player.duration;
      this.max = this.player.duration;
      this.update({ value: this.player.currentTime });
    }
  }, {
    key: "onChange",
    value: function onChange(states) {
      this.player.currentTime = states.value;
    }
  }]);
  return Progress;
}(Slider);

var Volume = function (_Slider) {
  babelHelpers.inherits(Volume, _Slider);

  function Volume(props, context) {
    babelHelpers.classCallCheck(this, Volume);

    var _this = babelHelpers.possibleConstructorReturn(this, (Volume.__proto__ || Object.getPrototypeOf(Volume)).call(this, props, context));

    _this.classList.add("amp-volume");
    _this.state.min = 0;
    _this.state.max = 100;
    _this.state.percent = _this.player.volume;
    _this.state.value = _this.player.volume * 100;
    _this.state.altText = "MSG_VOLUME";
    return _this;
  }

  babelHelpers.createClass(Volume, [{
    key: "format",
    value: function format(value) {
      return Math.round(value);
    }
  }, {
    key: "onvolumechange",
    value: function onvolumechange(event) {
      this.update({ percent: event.detail });
    }
  }, {
    key: "onChange",
    value: function onChange(value) {
      this.player.volume = value.percent;
    }
  }]);
  return Volume;
}(Slider);

var Toggle = function (_Control) {
  babelHelpers.inherits(Toggle, _Control);

  function Toggle(props, context) {
    babelHelpers.classCallCheck(this, Toggle);

    var _this = babelHelpers.possibleConstructorReturn(this, (Toggle.__proto__ || Object.getPrototypeOf(Toggle)).call(this, props, context));

    _this.state.toggled = false;
    _this.state.onlabel = "";
    _this.state.offlabel = "";
    return _this;
  }

  babelHelpers.createClass(Toggle, [{
    key: "toggle",
    value: function toggle() {
      return this.toggled = !this.toggled;
    }
  }, {
    key: "onClick",
    value: function onClick(event) {
      this.toggle();
    }
  }, {
    key: "toggled",
    set: function set(value) {
      if (value === this.state.toggled) return value;

      this.setState({ toggled: value });
      this.change(value);
    },
    get: function get() {
      return this.state.toggled;
    }
  }, {
    key: "propsList",
    get: function get() {
      var props = babelHelpers.get(Toggle.prototype.__proto__ || Object.getPrototypeOf(Toggle.prototype), "propsList", this);
      props["aria-checked"] = this.state.toggled;
      props["role"] = "switch";
      return props;
    }
  }]);
  return Toggle;
}(Control);

var Mute = function (_Toggle) {
  babelHelpers.inherits(Mute, _Toggle);

  function Mute(props, context) {
    babelHelpers.classCallCheck(this, Mute);

    var _this = babelHelpers.possibleConstructorReturn(this, (Mute.__proto__ || Object.getPrototypeOf(Mute)).call(this, props, context));

    _this.state.level = "";
    _this.classList.add("amp-mute");
    _this.state.altText = "MSG_MUTE";
    return _this;
  }

  babelHelpers.createClass(Mute, [{
    key: "onChange",
    value: function onChange() {
      var player = this.player;
      player.muted = !player.muted;
    }
  }, {
    key: "onvolumechange",
    value: function onvolumechange() {
      var volume = this.player.volume;
      var level = "";

      if (volume == 0) {
        level = "amp-muted";
      } else if (volume < 0.5) {
        level = "amp-low";
      }

      this.setState({ level: level });
    }
  }, {
    key: "className",
    get: function get() {
      return babelHelpers.get(Mute.prototype.__proto__ || Object.getPrototypeOf(Mute.prototype), "className", this) + " " + this.state.level;
    }
  }]);
  return Mute;
}(Toggle);

var Fullscreen = function (_Control) {
  babelHelpers.inherits(Fullscreen, _Control);

  function Fullscreen(props, context) {
    babelHelpers.classCallCheck(this, Fullscreen);

    var _this = babelHelpers.possibleConstructorReturn(this, (Fullscreen.__proto__ || Object.getPrototypeOf(Fullscreen)).call(this, props, context));

    _this.classList.add("amp-fullscreen");
    return _this;
  }

  babelHelpers.createClass(Fullscreen, [{
    key: "onfullscreenchange",
    value: function onfullscreenchange(event) {
      var key = event.detail ? "MSG_EXIT_FULLSCREEN" : "MSG_ENTER_FULLSCREEN";
      this.setState({ altText: key });
    }
  }, {
    key: "onClick",
    value: function onClick() {
      if (this.player.displayState == "normal") {
        this.player.enterFullScreen();
      } else {
        this.player.exitFullScreen();
      }
    }
  }]);
  return Fullscreen;
}(Control);

var Panel = function (_Component) {
  babelHelpers.inherits(Panel, _Component);

  function Panel(props, context) {
    babelHelpers.classCallCheck(this, Panel);

    var _this = babelHelpers.possibleConstructorReturn(this, (Panel.__proto__ || Object.getPrototypeOf(Panel)).call(this, props, context));

    _this.closeHandler = _this.closeHandler.bind(_this);
    return _this;
  }

  babelHelpers.createClass(Panel, [{
    key: "closeHandler",
    value: function closeHandler(event) {
      if (this.element === undefined || this.element.contains(event.target)) return;

      this.open = false;
      document.removeEventListener("click", this.closeHandler);
    }
  }, {
    key: "toggle",
    value: function toggle() {
      this.open = !this.open;
    }
  }, {
    key: "close",
    value: function close() {
      this.open = false;
    }
  }, {
    key: "open",
    set: function set(value) {
      if (value == this._open) return;

      this._open = value;
      this.classList.update({ "amp-open": this._open });

      if (this._open) {
        document.addEventListener("click", this.closeHandler);
        if (this.props.onopen) this.props.onopen(this);
      } else {
        if (this.props.onclose) this.props.onclose(this);
      }
    },
    get: function get() {
      return this._open;
    }
  }, {
    key: "propsList",
    get: function get() {
      var _babelHelpers$get = babelHelpers.get(Panel.prototype.__proto__ || Object.getPrototypeOf(Panel.prototype), "propsList", this),
          onclose = _babelHelpers$get.onclose,
          onopen = _babelHelpers$get.onopen,
          props = babelHelpers.objectWithoutProperties(_babelHelpers$get, ["onclose", "onopen"]);

      return props;
    }
  }]);
  return Panel;
}(Component);

var ListItem = function (_Control) {
  babelHelpers.inherits(ListItem, _Control);

  function ListItem(props, context) {
    babelHelpers.classCallCheck(this, ListItem);

    var _this = babelHelpers.possibleConstructorReturn(this, (ListItem.__proto__ || Object.getPrototypeOf(ListItem)).call(this, props, context));

    _this.classList.add("amp-list-item");
    _this.classList.remove("amp-icon");
    _this.classList.remove("amp-control");
    return _this;
  }

  babelHelpers.createClass(ListItem, [{
    key: "focus",
    value: function focus() {
      this.refs.element.focus();
    }
  }, {
    key: "onKeyDown",
    value: function onKeyDown(event) {
      var _this2 = this;

      if (this.mouseFocus == true) return;
      this.onKeyPress(event);

      if (event.type == "keydown" && (event.keyCode == 13 || event.keyCode == 32)) this.props.onClick(event) || this.onClick(event);else if (event.type == "keydown" && event.keyCode == 9 && this.element.nextElementSibling === null) {
        var _ret = function () {
          if (event.shiftKey) return {
              v: void 0
            };
          _this2.plugin.refs.settingsPanel.close();
          var tabable = document.getElementsByClassName("amp-control");
          //tabable[tabable.length-1].focus();
          setTimeout(function () {
            tabable[tabable.length - 1].focus();
          }, 1);
        }();

        if ((typeof _ret === "undefined" ? "undefined" : babelHelpers.typeof(_ret)) === "object") return _ret.v;
      }
    }
  }, {
    key: "render",
    value: function render() {
      return React.createElement(
        "div",
        babelHelpers.extends({ ref: "element" }, this.propsList, { role: "menuitem" }),
        this.children
      );
    }
  }]);
  return ListItem;
}(Control);

var Bitrate = function (_Panel) {
  babelHelpers.inherits(Bitrate, _Panel);

  function Bitrate(props, context) {
    babelHelpers.classCallCheck(this, Bitrate);

    var _this = babelHelpers.possibleConstructorReturn(this, (Bitrate.__proto__ || Object.getPrototypeOf(Bitrate)).call(this, props, context));

    _this.listOptions = [];
    _this.bitrateArray = [];
    _this.state.activeIndex = -1;
    _this.player.addEventListener("bitratelevelsloaded", _this.onBitrateLoaded.bind(_this));
    _this.player.addEventListener("bitratechanging", _this.onBitrateChange.bind(_this));
    return _this;
  }

  babelHelpers.createClass(Bitrate, [{
    key: "componentWillMount",
    value: function componentWillMount() {
      this.props.bitrate.bitrateArray && this.onBitrateLoaded();
      this.props.bitrate.bitrateIndex !== undefined && this.onBitrateChange();
      this.open = true;
    }
  }, {
    key: "clickHandler",
    value: function clickHandler(object, index) {
      this.player.setQuality(index);
    }
  }, {
    key: "onBitrateLoaded",
    value: function onBitrateLoaded(data) {
      var _this2 = this;

      this.bitrateArray = data ? data.data.levels : this.props.bitrate.bitrateArray;
      this.bitrateArray.forEach(function (item) {
        _this2.listOptions.push({ "label": item.bitrate });
      });
      this.setState({ redraw: true });
    }
  }, {
    key: "onBitrateChange",
    value: function onBitrateChange(data) {
      var autoLevel = false;
      try {
        autoLevel = this.player.playerCore.activePlaybackCore.player.autoLevelEnabled === true;
      } catch (e) {}

      var index = autoLevel ? -1 : data ? this.bitrateArray.indexOf(data.data) : this.props.bitrate.bitrateIndex;

      this.setState({ activeIndex: index });
    }
  }, {
    key: "render",
    value: function render() {

      var OptionsList = this.listOptions.map(function (object, index) {

        return React.createElement(
          ListItem,
          { key: index, onClick: this.clickHandler.bind(this, object, index) },
          React.createElement("button", { tabIndex: "-1", className: index === this.state.activeIndex ? 'amp-icon amp-list-item-selected' : 'amp-icon' }),
          React.createElement(
            "span",
            null,
            object.label / 1000,
            " Kbps"
          )
        );
      }, this);

      return React.createElement(
        "div",
        { ref: "element" },
        React.createElement(
          ListItem,
          { className: "amp-list-title", onClick: this.props.gotoSettings.bind(this) },
          React.createElement("button", { tabIndex: "-1", className: "amp-icon amp-icon-left" }),
          React.createElement(
            "span",
            null,
            "Quality"
          )
        ),
        React.createElement(
          ListItem,
          { onClick: this.clickHandler.bind(this, null, -1) },
          React.createElement("button", { tabIndex: "-1", className: -1 === this.state.activeIndex ? 'amp-icon amp-list-item-selected' : 'amp-icon' }),
          React.createElement(
            "span",
            null,
            "Auto"
          )
        ),
        OptionsList
      );
    }
  }]);
  return Bitrate;
}(Panel);

var Home = function (_Panel) {
  babelHelpers.inherits(Home, _Panel);

  function Home(props, context) {
    babelHelpers.classCallCheck(this, Home);

    var _this = babelHelpers.possibleConstructorReturn(this, (Home.__proto__ || Object.getPrototypeOf(Home)).call(this, props, context));

    _this.listOptions = [{ label: "Off" }];
    return _this;
  }

  babelHelpers.createClass(Home, [{
    key: "clickHandler",
    value: function clickHandler(object, index) {
      this.setState({ activeIndex: index });
      if (!index) {
        return this.props.settingsChange({ 'showing': false });
      }
      this.props.settingsChange({ "language": this.listOptions[index].label });
    }
  }, {
    key: "render",
    value: function render() {
      var _this2 = this;

      this.listOptions.splice(1);
      for (var lang in this.props.languages) {
        this.listOptions.push({ 'label': this.props.languages[lang] });
      }

      var OptionsList = this.listOptions.map(function (object, index) {
        var selected = !this.player.captioning.getHidden() && object.label == this.player.captioning.getTrack().language;
        if (this.player.captioning.getHidden() && index === 0) {
          selected = true;
        }
        return React.createElement(
          ListItem,
          { key: index, onClick: this.clickHandler.bind(this, object, index) },
          React.createElement("button", { className: selected ? 'amp-icon amp-list-item-selected' : 'amp-icon', tabIndex: "-1" }),
          React.createElement(
            "span",
            null,
            this.player.localization.getLanguageString(object.label) || object.label
          )
        );
      }, this);

      return React.createElement(
        "div",
        { ref: "element", className: "amp-captioning-home" },
        React.createElement(
          "div",
          null,
          React.createElement(
            "span",
            { className: "amp-list-highlight", onClick: this.props.gotoSettings.bind(this), onKeyDown: this.props.gotoSettings.bind(this), tabIndex: "0" },
            React.createElement("button", { className: "amp-icon amp-icon-left", tabIndex: "-1" }),
            React.createElement(
              "span",
              null,
              "Subtitles/CC"
            )
          ),
          React.createElement(
            "button",
            { onClick: function onClick(event) {
                return _this2.props.viewChange(event, "options");
              }, onKeyDown: function onKeyDown(event) {
                return _this2.props.viewChange(event, "options");
              }, className: "amp-option-button", tabIndex: "0" },
            "Options"
          )
        ),
        OptionsList
      );
    }
  }]);
  return Home;
}(Panel);

var Options = function (_Panel) {
  babelHelpers.inherits(Options, _Panel);

  function Options(props, context) {
    babelHelpers.classCallCheck(this, Options);

    var _this = babelHelpers.possibleConstructorReturn(this, (Options.__proto__ || Object.getPrototypeOf(Options)).call(this, props, context));

    _this.listOptions = [{ label: "Font Family", key: "fontFamily", value: "Arial" }, { label: "Font Color", key: "fontColor", value: "Red" }, { label: "Font Size", key: "fontSize", value: "100%" }, { label: "Font Opacity", key: "fontOpacity", value: "0%" }, { label: "Background Color", key: "backgroundColor", value: "Black" }, { label: "Background Opacity", key: "backgroundOpacity", value: "0%" }, { label: "Window Color", key: "windowColor", value: "Red" }, { label: "Window Opacity", key: "windowOpacity", value: "0%" }, { label: "Character Edge Style", key: "edgeType", value: "None" }, { label: "Scroll", key: "scroll", value: "Pop-out" }];
    return _this;
  }

  babelHelpers.createClass(Options, [{
    key: "render",
    value: function render() {
      var _this3 = this;

      var OptionsList = this.listOptions.map(function (object, index) {
        var _this2 = this;

        var parentKey = object.key.match(/(Color|Opacity|fontSize)/) ? object.key + "Label" : object.key;
        return React.createElement(
          ListItem,
          { key: object.key, onClick: function onClick(event) {
              return _this2.props.viewChange(event, object.key);
            } },
          React.createElement(
            "span",
            { className: "amp-label" },
            object.label
          ),
          React.createElement("button", { className: "amp-icon amp-icon-right amp-right", tabIndex: "-1" }),
          React.createElement(
            "span",
            { className: "amp-right" },
            this.props.captionsettings[parentKey]
          )
        );
      }, this);

      return React.createElement(
        "div",
        { className: "amp-captioning-options" },
        React.createElement(
          ListItem,
          { className: "amp-list-title", onClick: function onClick(event) {
              return _this3.props.viewChange(event, "home");
            } },
          React.createElement("button", { className: "amp-icon amp-icon-left", tabIndex: "-1" }),
          React.createElement(
            "span",
            null,
            "Options"
          )
        ),
        OptionsList
      );
    }
  }]);
  return Options;
}(Panel);

var BackgroundColor = function (_Panel) {
  babelHelpers.inherits(BackgroundColor, _Panel);

  function BackgroundColor(props, context) {
    babelHelpers.classCallCheck(this, BackgroundColor);

    var _this = babelHelpers.possibleConstructorReturn(this, (BackgroundColor.__proto__ || Object.getPrototypeOf(BackgroundColor)).call(this, props, context));

    _this.listOptions = [{ label: "White", value: "rgb(255, 255, 255)" }, { label: "Yellow", value: "rgb(255, 255, 0)" }, { label: "Green", value: "rgb(0, 128, 0)" }, { label: "Cyan", value: "rgb(0, 255, 255)" }, { label: "Blue", value: "rgb(0, 0, 255)" }, { label: "Magenta", value: "rgb(255, 0, 255)" }, { label: "Red", value: "rgb(255, 0, 0)" }, { label: "Black", value: "rgb(0, 0, 0)" }];
    _this.listOptions.map(function (object, index) {
      if (object.label === props.captionsettings['backgroundColorLabel']) {
        this.state.activeIndex = index;
      }
    }, _this);
    return _this;
  }

  babelHelpers.createClass(BackgroundColor, [{
    key: "clickHandler",
    value: function clickHandler(object, index) {
      this.setState({ activeIndex: index });
      this.props.settingsChange({ "backgroundColor": { "label": object.label, "value": object.value } });
    }
  }, {
    key: "render",
    value: function render() {
      var _this2 = this;

      var OptionsList = this.listOptions.map(function (object, index) {

        return React.createElement(
          ListItem,
          { key: index, onClick: this.clickHandler.bind(this, object, index) },
          React.createElement("button", { className: index === this.state.activeIndex ? 'amp-icon amp-list-item-selected' : 'amp-icon', tabIndex: "-1" }),
          React.createElement(
            "span",
            null,
            object.label
          )
        );
      }, this);

      return React.createElement(
        "div",
        null,
        React.createElement(
          ListItem,
          { className: "amp-list-title", onClick: function onClick(event) {
              return _this2.props.viewChange(event, "options");
            } },
          React.createElement("button", { className: "amp-icon amp-icon-left", tabIndex: "-1" }),
          React.createElement(
            "span",
            null,
            "Background Color"
          )
        ),
        OptionsList
      );
    }
  }]);
  return BackgroundColor;
}(Panel);

var BackgroundOpacity = function (_Panel) {
  babelHelpers.inherits(BackgroundOpacity, _Panel);

  function BackgroundOpacity(props, context) {
    babelHelpers.classCallCheck(this, BackgroundOpacity);

    var _this = babelHelpers.possibleConstructorReturn(this, (BackgroundOpacity.__proto__ || Object.getPrototypeOf(BackgroundOpacity)).call(this, props, context));

    _this.listOptions = [{ label: "0%", value: "0" }, { label: "25%", value: ".25" }, { label: "50%", value: ".5" }, { label: "75%", value: ".75" }, { label: "100%", value: "1" }];
    _this.listOptions.map(function (object, index) {
      if (object.label === props.captionsettings['backgroundOpacityLabel']) {
        this.state.activeIndex = index;
      }
    }, _this);
    return _this;
  }

  babelHelpers.createClass(BackgroundOpacity, [{
    key: "clickHandler",
    value: function clickHandler(object, index) {
      this.setState({ activeIndex: index });
      this.props.settingsChange({ "backgroundOpacity": { "label": object.label, "value": object.value } });
    }
  }, {
    key: "render",
    value: function render() {
      var _this2 = this;

      var OptionsList = this.listOptions.map(function (object, index) {

        return React.createElement(
          ListItem,
          { key: index, onClick: this.clickHandler.bind(this, object, index) },
          React.createElement("button", { className: index === this.state.activeIndex ? 'amp-icon amp-list-item-selected' : 'amp-icon', tabIndex: "-1" }),
          React.createElement(
            "span",
            null,
            object.label
          )
        );
      }, this);

      return React.createElement(
        "div",
        null,
        React.createElement(
          ListItem,
          { className: "amp-list-title", onClick: function onClick(event) {
              return _this2.props.viewChange(event, "options");
            } },
          React.createElement("button", { className: "amp-icon amp-icon-left", tabIndex: "-1" }),
          React.createElement(
            "span",
            null,
            "Background Opacity"
          )
        ),
        OptionsList
      );
    }
  }]);
  return BackgroundOpacity;
}(Panel);

var CharacterEdgeStyle = function (_Panel) {
  babelHelpers.inherits(CharacterEdgeStyle, _Panel);

  function CharacterEdgeStyle(props, context) {
    babelHelpers.classCallCheck(this, CharacterEdgeStyle);

    var _this = babelHelpers.possibleConstructorReturn(this, (CharacterEdgeStyle.__proto__ || Object.getPrototypeOf(CharacterEdgeStyle)).call(this, props, context));

    _this.listOptions = [{ label: "None", value: "" }, { label: "Depressed", value: "" }, { label: "Left Drop Shadow", value: "" }, { label: "Raised", value: "" }, { label: "Right Drop Shadow", value: "" }, { label: "Uniform", value: "" }];
    _this.listOptions.map(function (object, index) {
      if (object.label === props.captionsettings['edgeType']) {
        this.state.activeIndex = index;
      }
    }, _this);

    return _this;
  }

  babelHelpers.createClass(CharacterEdgeStyle, [{
    key: "clickHandler",
    value: function clickHandler(object, index) {
      this.setState({ activeIndex: index });
      this.props.settingsChange({ "edgeType": { "label": object.label, "value": object.value } });
    }
  }, {
    key: "render",
    value: function render() {
      var _this2 = this;

      var OptionsList = this.listOptions.map(function (object, index) {

        return React.createElement(
          ListItem,
          { key: index, onClick: this.clickHandler.bind(this, object, index) },
          React.createElement("button", { className: index === this.state.activeIndex ? 'amp-icon amp-list-item-selected' : 'amp-icon', tabIndex: "-1" }),
          React.createElement(
            "span",
            null,
            object.label
          )
        );
      }, this);

      return React.createElement(
        "div",
        null,
        React.createElement(
          ListItem,
          { className: "amp-list-title", onClick: function onClick(event) {
              return _this2.props.viewChange(event, "options");
            } },
          React.createElement("button", { className: "amp-icon amp-icon-left", tabIndex: "-1" }),
          React.createElement(
            "span",
            null,
            "Character Edge Style"
          )
        ),
        OptionsList
      );
    }
  }]);
  return CharacterEdgeStyle;
}(Panel);

var FontColor = function (_Panel) {
  babelHelpers.inherits(FontColor, _Panel);

  function FontColor(props, context) {
    babelHelpers.classCallCheck(this, FontColor);

    var _this = babelHelpers.possibleConstructorReturn(this, (FontColor.__proto__ || Object.getPrototypeOf(FontColor)).call(this, props, context));

    _this.listOptions = [{ label: "White", value: "rgb(255, 255, 255)" }, { label: "Yellow", value: "rgb(255, 255, 0)" }, { label: "Green", value: "rgb(0, 128, 0)" }, { label: "Cyan", value: "rgb(0, 255, 255)" }, { label: "Blue", value: "rgb(0, 0, 255)" }, { label: "Magenta", value: "rgb(255, 0, 255)" }, { label: "Red", value: "rgb(255, 0, 0)" }, { label: "Black", value: "rgb(0, 0, 0)" }];
    _this.listOptions.map(function (object, index) {
      if (object.label === props.captionsettings['fontColorLabel']) {
        this.state.activeIndex = index;
      }
    }, _this);

    return _this;
  }

  babelHelpers.createClass(FontColor, [{
    key: "clickHandler",
    value: function clickHandler(object, index) {
      this.setState({ activeIndex: index });
      this.props.settingsChange({ "fontColor": { "label": object.label, "value": object.value } });
    }
  }, {
    key: "render",
    value: function render() {
      var _this2 = this;

      var OptionsList = this.listOptions.map(function (object, index) {

        return React.createElement(
          ListItem,
          { key: index, onClick: this.clickHandler.bind(this, object, index) },
          React.createElement("button", { className: index === this.state.activeIndex ? 'amp-icon amp-list-item-selected' : 'amp-icon', tabIndex: "-1" }),
          React.createElement(
            "span",
            null,
            object.label
          )
        );
      }, this);

      return React.createElement(
        "div",
        null,
        React.createElement(
          ListItem,
          { className: "amp-list-title", onClick: function onClick(event) {
              return _this2.props.viewChange(event, "options");
            } },
          React.createElement("button", { className: "amp-icon amp-icon-left", tabIndex: "-1" }),
          React.createElement(
            "span",
            null,
            "Font Color"
          )
        ),
        OptionsList
      );
    }
  }]);
  return FontColor;
}(Panel);

var FontFamily = function (_Panel) {
  babelHelpers.inherits(FontFamily, _Panel);

  function FontFamily(props, context) {
    babelHelpers.classCallCheck(this, FontFamily);

    var _this = babelHelpers.possibleConstructorReturn(this, (FontFamily.__proto__ || Object.getPrototypeOf(FontFamily)).call(this, props, context));

    _this.listOptions = [{ label: "Monospaced Serif", value: "'Courier New', Courier, 'Nimbus Mono L', 'Cutive Mono', monospace" }, { label: "Proportional Serif", value: "'Times New Roman', Times, Georgia, Cambria, 'PT Serif Caption', serif" }, { label: "Monospaced Sans-Serif", value: "'Deja Vu Sans Mono', 'Lucida Console', Monaco, Consolas, 'PT Mono', monospace" }, { label: "Proportional Sans-Serif", value: "Roboto, 'Arial Unicode Ms', Arial, Helvetica, Verdana, 'PT Sans Caption', sans-serif" }, { label: "Casual", value: "'Comic Sans MS', Impact, Handlee, fantasy" }, { label: "Cursive", value: "'Monotype Corsiva', 'URW Chancery L', 'Apple Chancery', 'Dancing Script', cursive" }, { label: "Small Capitals", value: "'Arial Unicode Ms', Arial, Helvetica, Verdana, 'Marcellus SC', sans-serif; font-variant: small-caps" }];
    _this.listOptions.map(function (object, index) {
      if (object.label === props.captionsettings['fontFamily']) {
        this.state.activeIndex = index;
      }
    }, _this);

    return _this;
  }

  babelHelpers.createClass(FontFamily, [{
    key: "clickHandler",
    value: function clickHandler(object, index) {
      this.setState({ activeIndex: index });
      this.props.settingsChange({ "fontFamily": { "label": object.label, "value": object.value } });
    }
  }, {
    key: "render",
    value: function render() {
      var _this2 = this;

      var OptionsList = this.listOptions.map(function (object, index) {

        return React.createElement(
          ListItem,
          { key: index, onClick: this.clickHandler.bind(this, object, index) },
          React.createElement("button", { className: index === this.state.activeIndex ? 'amp-icon amp-list-item-selected' : 'amp-icon', tabIndex: "-1" }),
          React.createElement(
            "span",
            null,
            object.label
          )
        );
      }, this);

      return React.createElement(
        "div",
        null,
        React.createElement(
          ListItem,
          { className: "amp-list-title", onClick: function onClick(event) {
              return _this2.props.viewChange(event, "options");
            } },
          React.createElement("button", { className: "amp-icon amp-icon-left", tabIndex: "-1" }),
          React.createElement(
            "span",
            null,
            "Font Family"
          )
        ),
        OptionsList
      );
    }
  }]);
  return FontFamily;
}(Panel);

var FontOpacity = function (_Panel) {
  babelHelpers.inherits(FontOpacity, _Panel);

  function FontOpacity(props, context) {
    babelHelpers.classCallCheck(this, FontOpacity);

    var _this = babelHelpers.possibleConstructorReturn(this, (FontOpacity.__proto__ || Object.getPrototypeOf(FontOpacity)).call(this, props, context));

    _this.listOptions = [{ label: "25%", value: ".25" }, { label: "50%", value: ".5" }, { label: "75%", value: ".75" }, { label: "100%", value: "1" }];

    _this.listOptions.map(function (object, index) {
      if (object.label === props.captionsettings['fontOpacityLabel']) {
        this.state.activeIndex = index;
      }
    }, _this);

    return _this;
  }

  babelHelpers.createClass(FontOpacity, [{
    key: "clickHandler",
    value: function clickHandler(object, index) {
      this.setState({ activeIndex: index });
      this.props.settingsChange({ "fontOpacity": { "label": object.label, "value": object.value } });
    }
  }, {
    key: "render",
    value: function render() {
      var _this2 = this;

      var OptionsList = this.listOptions.map(function (object, index) {
        return React.createElement(
          ListItem,
          { key: index, onClick: this.clickHandler.bind(this, object, index) },
          React.createElement("button", { className: index === this.state.activeIndex ? 'amp-icon amp-list-item-selected' : 'amp-icon', tabIndex: "-1" }),
          React.createElement(
            "span",
            null,
            object.label
          )
        );
      }, this);

      return React.createElement(
        "div",
        null,
        React.createElement(
          ListItem,
          { className: "amp-list-title", onClick: function onClick(event) {
              return _this2.props.viewChange(event, "options");
            } },
          React.createElement("button", { className: "amp-icon amp-icon-left", tabIndex: "-1" }),
          React.createElement(
            "span",
            null,
            "Font Opacity"
          )
        ),
        OptionsList
      );
    }
  }]);
  return FontOpacity;
}(Panel);

var FontSize = function (_Panel) {
  babelHelpers.inherits(FontSize, _Panel);

  function FontSize(props, context) {
    babelHelpers.classCallCheck(this, FontSize);

    var _this = babelHelpers.possibleConstructorReturn(this, (FontSize.__proto__ || Object.getPrototypeOf(FontSize)).call(this, props, context));

    _this.listOptions = [{ label: "70%", value: "Extra small" }, { label: "100%", value: "Small" }, { label: "150%", value: "Medium" }, { label: "200%", value: "Large" }, { label: "300%", value: "Extra large" }];

    _this.listOptions.map(function (object, index) {
      if (object.label === props.captionsettings['fontSizeLabel']) {
        this.state.activeIndex = index;
      }
    }, _this);

    return _this;
  }

  babelHelpers.createClass(FontSize, [{
    key: "clickHandler",
    value: function clickHandler(object, index) {
      this.setState({ activeIndex: index });
      this.props.settingsChange({ "fontSize": { "label": object.label, "value": object.value } });
    }
  }, {
    key: "render",
    value: function render() {
      var _this2 = this;

      var OptionsList = this.listOptions.map(function (object, index) {

        return React.createElement(
          ListItem,
          { key: index, onClick: this.clickHandler.bind(this, object, index) },
          React.createElement("button", { className: index === this.state.activeIndex ? 'amp-icon amp-list-item-selected' : 'amp-icon', tabIndex: "-1" }),
          React.createElement(
            "span",
            null,
            object.label
          )
        );
      }, this);

      return React.createElement(
        "div",
        null,
        React.createElement(
          ListItem,
          { className: "amp-list-title", onClick: function onClick(event) {
              return _this2.props.viewChange(event, "options");
            } },
          React.createElement("button", { className: "amp-icon amp-icon-left", tabIndex: "-1" }),
          React.createElement(
            "span",
            null,
            "Font Size"
          )
        ),
        OptionsList
      );
    }
  }]);
  return FontSize;
}(Panel);

var WindowColor = function (_Panel) {
  babelHelpers.inherits(WindowColor, _Panel);

  function WindowColor(props, context) {
    babelHelpers.classCallCheck(this, WindowColor);

    var _this = babelHelpers.possibleConstructorReturn(this, (WindowColor.__proto__ || Object.getPrototypeOf(WindowColor)).call(this, props, context));

    _this.listOptions = [{ label: "White", value: "rgb(255, 255, 255)" }, { label: "Yellow", value: "rgb(255, 255, 0)" }, { label: "Green", value: "rgb(0, 128, 0)" }, { label: "Cyan", value: "rgb(0, 255, 255)" }, { label: "Blue", value: "rgb(0, 0, 255)" }, { label: "Magenta", value: "rgb(255, 0, 255)" }, { label: "Red", value: "rgb(255, 0, 0)" }, { label: "Black", value: "rgb(0, 0, 0)" }];

    _this.listOptions.map(function (object, index) {
      if (object.label === props.captionsettings['windowColorLabel']) {
        this.state.activeIndex = index;
      }
    }, _this);

    return _this;
  }

  babelHelpers.createClass(WindowColor, [{
    key: "clickHandler",
    value: function clickHandler(object, index) {
      this.setState({ activeIndex: index });
      this.props.settingsChange({ "windowColor": { "label": object.label, "value": object.value } });
    }
  }, {
    key: "render",
    value: function render() {
      var _this2 = this;

      var OptionsList = this.listOptions.map(function (object, index) {

        return React.createElement(
          ListItem,
          { key: index, onClick: this.clickHandler.bind(this, object, index) },
          React.createElement("button", { className: index === this.state.activeIndex ? 'amp-icon amp-list-item-selected' : 'amp-icon', tabIndex: "-1" }),
          React.createElement(
            "span",
            null,
            object.label
          )
        );
      }, this);

      return React.createElement(
        "div",
        null,
        React.createElement(
          ListItem,
          { className: "amp-list-title", onClick: function onClick(event) {
              return _this2.props.viewChange(event, "options");
            } },
          React.createElement("button", { className: "amp-icon amp-icon-left", tabIndex: "-1" }),
          React.createElement(
            "span",
            null,
            "Window Color"
          )
        ),
        OptionsList
      );
    }
  }]);
  return WindowColor;
}(Panel);

var WindowOpacity = function (_Panel) {
  babelHelpers.inherits(WindowOpacity, _Panel);

  function WindowOpacity(props, context) {
    babelHelpers.classCallCheck(this, WindowOpacity);

    var _this = babelHelpers.possibleConstructorReturn(this, (WindowOpacity.__proto__ || Object.getPrototypeOf(WindowOpacity)).call(this, props, context));

    _this.listOptions = [{ label: "0%", value: "0" }, { label: "25%", value: ".25" }, { label: "50%", value: ".5" }, { label: "75%", value: ".75" }, { label: "100%", value: "1" }];

    _this.listOptions.map(function (object, index) {
      if (object.label === props.captionsettings['windowOpacityLabel']) {
        this.state.activeIndex = index;
      }
    }, _this);

    return _this;
  }

  babelHelpers.createClass(WindowOpacity, [{
    key: "clickHandler",
    value: function clickHandler(object, index) {
      this.setState({ activeIndex: index });
      this.props.settingsChange({ "windowOpacity": { "label": object.label, "value": object.value } });
    }
  }, {
    key: "render",
    value: function render() {
      var _this2 = this;

      var OptionsList = this.listOptions.map(function (object, index) {

        return React.createElement(
          ListItem,
          { key: index, onClick: this.clickHandler.bind(this, object, index) },
          React.createElement("button", { className: index === this.state.activeIndex ? 'amp-icon amp-list-item-selected' : 'amp-icon', tabIndex: "-1" }),
          React.createElement(
            "span",
            null,
            object.label
          )
        );
      }, this);

      return React.createElement(
        "div",
        null,
        React.createElement(
          ListItem,
          { className: "amp-list-item", onClick: function onClick(event) {
              return _this2.props.viewChange(event, "options");
            } },
          React.createElement("button", { className: "amp-icon amp-icon-left", tabIndex: "-1" }),
          React.createElement(
            "span",
            null,
            "Window Opacity"
          )
        ),
        OptionsList
      );
    }
  }]);
  return WindowOpacity;
}(Panel);

var ScrollType = function (_Panel) {
  babelHelpers.inherits(ScrollType, _Panel);

  function ScrollType(props, context) {
    babelHelpers.classCallCheck(this, ScrollType);

    var _this = babelHelpers.possibleConstructorReturn(this, (ScrollType.__proto__ || Object.getPrototypeOf(ScrollType)).call(this, props, context));

    _this.listOptions = [{ label: "Pop-out", value: "pop-out" }, { label: "Roll-on", value: "roll-on" }, { label: "Paint-on", value: "paint-on" }];

    _this.listOptions.map(function (object, index) {
      if (object.label === props.captionsettings['scroll']) {
        this.state.activeIndex = index;
      }
    }, _this);

    return _this;
  }

  babelHelpers.createClass(ScrollType, [{
    key: "clickHandler",
    value: function clickHandler(object, index) {
      this.setState({ activeIndex: index });
      this.props.settingsChange({ "scroll": { "label": object.label, "value": object.value } });
    }
  }, {
    key: "render",
    value: function render() {
      var _this2 = this;

      var OptionsList = this.listOptions.map(function (object, index) {

        return React.createElement(
          ListItem,
          { key: index, onClick: this.clickHandler.bind(this, object, index) },
          React.createElement("button", { className: index === this.state.activeIndex ? 'amp-icon amp-list-item-selected' : 'amp-icon', tabIndex: "-1" }),
          React.createElement(
            "span",
            null,
            object.label
          )
        );
      }, this);

      return React.createElement(
        "div",
        null,
        React.createElement(
          ListItem,
          { className: "amp-list-title", onClick: function onClick(event) {
              return _this2.props.viewChange(event, "options");
            } },
          React.createElement("button", { className: "amp-icon amp-icon-left", tabIndex: "-1" }),
          React.createElement(
            "span",
            null,
            "Scroll Type"
          )
        ),
        OptionsList
      );
    }
  }]);
  return ScrollType;
}(Panel);

var CaptionSettings = function (_Panel) {
  babelHelpers.inherits(CaptionSettings, _Panel);

  function CaptionSettings(props, context) {
    babelHelpers.classCallCheck(this, CaptionSettings);

    var _this = babelHelpers.possibleConstructorReturn(this, (CaptionSettings.__proto__ || Object.getPrototypeOf(CaptionSettings)).call(this, props, context));

    _this.state.languages = [];
    _this.state.keyDown = false;
    _this.state.languageSelected = null;
    if (_this.props.captionState) {
      _this.state.captionsettings = _this.props.captionState;
    } else {
      _this.state.captionsettings = {
        "edgeType": "None",
        "fontFamily": "Monospaced Serif",
        "fontSize": "Small",
        "fontSizeLabel": "100%",
        "scroll": "Pop-out",
        "backgroundColor": "rgba(255, 255, 255, 1)",
        "fontColor": "rgba(0, 0, 0, 1)",
        "windowColor": "rgba(255, 255, 255, 1)",
        "edgeColor": "rgba(128,128,128, 0.7)",
        "fontColorLabel": "Black",
        "windowColorLabel": "White",
        "backgroundColorLabel": "White",
        "windowOpacityLabel": "100%",
        "fontOpacityLabel": "100%",
        "backgroundOpacityLabel": "100%",
        "languageLabel": "off",
        "visible": null
      };
    }

    _this.state.viewChange = _this.changeView.bind(_this);
    _this.state.settingsChange = _this.changeSettings.bind(_this);
    _this.state.level = "home";
    _this.player.captioning.addEventListener("tracksloaded", _this.tracksloaded.bind(_this));
    _this.player.captioning.addEventListener("trackselected", _this.trackselected.bind(_this));
    return _this;
  }

  babelHelpers.createClass(CaptionSettings, [{
    key: "componentWillMount",
    value: function componentWillMount() {
      this.props.captionTracks && this.tracksloaded();
      this.open = true;
    }
  }, {
    key: "tracksloaded",
    value: function tracksloaded(data) {
      var languages = [];
      var tracks = data ? data.detail : this.props.captionTracks;
      var len = tracks.length;
      var track = null;

      for (var i = 0; i < len; i++) {
        track = tracks[i];
        if (track.kind != "captions") continue;
        languages.push(track.language || "Unknown CC");
      }
      this.setState({ languages: languages });
    }
  }, {
    key: "focus",
    value: function focus(event) {
      this.refs.element.firstChild.children[1].focus();
    }
  }, {
    key: "trackselected",
    value: function trackselected(event) {
      this.state.languageSelected = event.detail.language;
    }
  }, {
    key: "selectLanguage",
    value: function selectLanguage(lang) {
      this.showing = true;
      this.player.captioning.selectTrackByLanguage(lang);
    }
  }, {
    key: "setCaptionSettings",
    value: function setCaptionSettings() {
      var settingObject = Object.assign({}, this.state.captionsettings);
      for (var key in settingObject) {
        if (key.endsWith('Label')) {
          delete settingObject[key];
        }
      }
      settingObject.visible = !this.showing;
      this.player.captioning.changeSettings(settingObject);
    }
  }, {
    key: "changeView",
    value: function changeView(event, toState) {
      var _this2 = this;

      if (/keydown/.test(event.type)) {
        if (event.keyCode == 13 || event.keyCode == 32) {
          this.keyDown = true;
        } else {
          return;
        }
      }

      setTimeout(function () {
        _this2.setState({ level: toState });
      }, 100);
    }
  }, {
    key: "changeSettings",
    value: function changeSettings(toLevel) {
      if ((typeof toLevel === "undefined" ? "undefined" : babelHelpers.typeof(toLevel)) === "object") {
        var object = toLevel;
        for (var key in object) {
          if (object.hasOwnProperty(key)) {
            var value = object[key];
            switch (key) {
              case "showing":
                this.showing = false;
                break;
              case "language":
                this.state.lang = value;
                this.state.captionsettings.languageLabel = value;
                this.selectLanguage(value);
                break;
              case "fontSize":
                this.state.captionsettings[key] = value['value'];
                this.state.captionsettings[key + 'Label'] = value['label'];
                break;
              case "edgeType":
              case "fontFamily":
              case "scroll":
                this.state.captionsettings[key] = value['label'];
                break;
              case "backgroundColor":
              case "fontColor":
              case "windowColor":
                var matchColors = /rgba\((\d{1,3}), (\d{1,3}), (\d{1,3}), ((\d{0,1}.\d{1,2})|(\d{1}))?\)/;
                var opacity = matchColors.exec(this.state.captionsettings[key])[4];
                if ((typeof value === "undefined" ? "undefined" : babelHelpers.typeof(value)) === "object") {
                  this.state.captionsettings[key + "Label"] = value.label;
                  value = value.value;
                }
                this.state.captionsettings[key] = value.replace(")", ", " + opacity + ")").replace("rgb", "rgba");
                break;
              case "backgroundOpacity":
              case "fontOpacity":
              case "windowOpacity":
                if ((typeof value === "undefined" ? "undefined" : babelHelpers.typeof(value)) === "object") {
                  this.state.captionsettings[key + "Label"] = value.label;
                  value = value.value;
                }
                key = key.replace("Opacity", "Color");
                matchColors = /rgba\((\d{1,3}), (\d{1,3}), (\d{1,3}), ((\d{0,1}.\d{1,2})|(\d{1}))?\)/;
                var rgba = matchColors.exec(this.state.captionsettings[key]);
                this.state.captionsettings[key] = "rgba(" + rgba[1] + ", " + rgba[2] + ", " + rgba[3] + ", " + value + ")";
                break;

              default:

            }
            this.setCaptionSettings();
          }
        }

        return;
      }
    }
  }, {
    key: "componentDidUpdate",
    value: function componentDidUpdate(prevProps, prevState) {
      if (this.keyDown) {
        this.refs.element.firstChild.children[1].focus();
        this.keyDown = false;
      }
    }
  }, {
    key: "getCurrentPage",
    value: function getCurrentPage() {

      switch (this.state.level) {
        case "home":
          return React.createElement(Home, babelHelpers.extends({ languages: this.state.languages }, this.state, { gotoSettings: this.props.gotoSettings.bind(this) }));
          break;
        case "options":
          return React.createElement(Options, this.state);
          break;
        case "fontFamily":
          return React.createElement(FontFamily, this.state);
          break;
        case "fontColor":
          return React.createElement(FontColor, this.state);
          break;
        case "fontSize":
          return React.createElement(FontSize, this.state);
          break;
        case "fontOpacity":
          return React.createElement(FontOpacity, this.state);
          break;
        case "backgroundColor":
          return React.createElement(BackgroundColor, this.state);
          break;
        case "backgroundOpacity":
          return React.createElement(BackgroundOpacity, this.state);
          break;
        case "windowColor":
          return React.createElement(WindowColor, this.state);
          break;
        case "windowOpacity":
          return React.createElement(WindowOpacity, this.state);
          break;
        case "edgeType":
          return React.createElement(CharacterEdgeStyle, this.state);
          break;
        case "scroll":
          return React.createElement(ScrollType, this.state);

      }
    }
  }, {
    key: "render",
    value: function render() {
      var localization = this.player.localization;
      return React.createElement(
        "div",
        { ref: "element", role: "menu" },
        this.getCurrentPage()
      );
    }
  }, {
    key: "showing",
    set: function set(value) {
      this.state.captionsettings.visible = value;
      this.player.captioning.setHidden(!value);
    },
    get: function get() {
      return this.player.captioning.getHidden();
    }
  }]);
  return CaptionSettings;
}(Panel);

var PlaybackRate = function (_Panel) {
  babelHelpers.inherits(PlaybackRate, _Panel);

  function PlaybackRate(props, context) {
    babelHelpers.classCallCheck(this, PlaybackRate);

    var _this = babelHelpers.possibleConstructorReturn(this, (PlaybackRate.__proto__ || Object.getPrototypeOf(PlaybackRate)).call(this, props, context));

    _this.listOptions = [{ "label": "0.25", "value": "0.25" }, { "label": ".5", "value": ".5" }, { "label": "Normal", "value": "1" }, { "label": "1.25", "value": "1.25" }, { "label": "1.5", "value": "1.5" }, { "label": "2", "value": "2" }];
    if (_this.props.playbackState != null) {
      _this.state.activeIndex = _this.props.playbackState;
    } else {
      _this.state.activeIndex = 2;
    }
    _this.classList.add("amp-playback-rate");
    return _this;
  }

  babelHelpers.createClass(PlaybackRate, [{
    key: "clickHandler",
    value: function clickHandler(object, index) {
      this.player.setPlaybackRate(object.value);
      this.props.playbackrate.playbackSettingState = index;
      this.setState({ activeIndex: index });
    }
  }, {
    key: "render",
    value: function render() {

      var OptionsList = this.listOptions.map(function (object, index) {
        return React.createElement(
          ListItem,
          { key: index, onClick: this.clickHandler.bind(this, object, index) },
          React.createElement("button", { tabIndex: "-1", className: parseFloat(object.value) === parseFloat(this.player.getPlaybackRate()) ? 'amp-icon amp-list-item-selected' : 'amp-icon' }),
          React.createElement(
            "span",
            null,
            object['label']
          )
        );
      }, this);

      return React.createElement(
        "div",
        { ref: "element" },
        React.createElement(
          ListItem,
          { className: "amp-list-title", onClick: this.props.gotoSettings.bind(this) },
          React.createElement("button", { tabIndex: "-1", className: "amp-icon amp-icon-left" }),
          React.createElement(
            "span",
            null,
            "Speed"
          )
        ),
        OptionsList
      );
    }
  }]);
  return PlaybackRate;
}(Panel);

var Settings = function (_Panel) {
  babelHelpers.inherits(Settings, _Panel);

  function Settings(props, context) {
    babelHelpers.classCallCheck(this, Settings);

    var _this = babelHelpers.possibleConstructorReturn(this, (Settings.__proto__ || Object.getPrototypeOf(Settings)).call(this, props, context));

    _this.state = {
      settingsLevel: 0,
      bitrateLabel: "Auto",
      playbackRateLabel: 1,
      captioningSettingState: null,
      playbackSettingState: null
    };
    _this.state.keyDown = false;
    _this.player.captioning.addEventListener("trackselected", _this.trackselected.bind(_this));
    _this.player.captioning.addEventListener("tracksloaded", _this.tracksloaded.bind(_this));
    _this.player.addEventListener("bitratechanging", _this.bitrateChange.bind(_this));
    _this.player.addEventListener("bitratelevelsloaded", _this.bitratesLoaded.bind(_this));
    return _this;
  }

  babelHelpers.createClass(Settings, [{
    key: "toggle",
    value: function toggle() {
      this.open = !this.open;
      {
        this.state.settingsLevel = 0;
      }
    }
  }, {
    key: "onKeyDown",
    value: function onKeyDown(event) {
      if (event.keyCode == 13 || event.keyCode == 32) {
        this.state.keyDown = true;
        this.toggle();
      }
    }
  }, {
    key: "trackselected",
    value: function trackselected(track) {
      var lang = this.player.localization.getLanguageString(track.detail.language) || track.detail.language || "None";
      this.setState({ language: lang });
    }
  }, {
    key: "tracksloaded",
    value: function tracksloaded(data) {
      this.state.captioningTracks = data.detail;
    }
  }, {
    key: "bitratesLoaded",
    value: function bitratesLoaded(event) {
      this.state.bitrateArray = event.data.levels;
    }
  }, {
    key: "bitrateChange",
    value: function bitrateChange(event) {
      var brLabel = event.detail.bitrate ? event.detail.bitrate / 1000 + "Kbps" : "Auto";
      this.state.bitrateIndex = this.state.bitrateArray ? this.state.bitrateArray.indexOf(event.detail) : -1;
      this.setState({ bitrateLabel: brLabel });
    }
  }, {
    key: "changeState",
    value: function changeState(value, event) {
      var _this2 = this;

      if (event.type == "keydown" && (event.keyCode == 13 || event.keyCode == 32) && this.mouseFocus != true) this.state.keyDown = true;
      setTimeout(function () {
        _this2.setState({ settingsLevel: value });
      }, 100);
    }
  }, {
    key: "componentWillUpdate",
    value: function componentWillUpdate(nextProps, nextState) {
      if (nextState.settingsLevel === 0) {
        if (this.state.settingsLevel === 1) this.setState({ 'captioningSettingState': this.refs.firstElem.state.captionsettings });else if (this.state.settingsLevel === 3) this.setState({ 'playbackSettingState': this.refs.firstElem.state.activeIndex });
      }
    }
  }, {
    key: "componentDidUpdate",
    value: function componentDidUpdate(prevProps, prevState) {

      if (this.state.keyDown) {
        if (typeof this.refs.firstElem.focus === "function") {
          this.refs.firstElem.focus();
        } else {
          this.refs.firstElem.refs.element.childNodes[1].focus();
        }
        this.state.keyDown = false;
      }
    }
  }, {
    key: "render",
    value: function render() {
      switch (this.state.settingsLevel) {
        case 0:
          return React.createElement(
            "div",
            babelHelpers.extends({ ref: "element" }, this.propsList, { className: "amp-settings amp-panel " + this.className, role: "menu" }),
            React.createElement(
              ListItem,
              { ref: "firstElem", onClick: this.changeState.bind(this, 1) },
              React.createElement(
                "span",
                { className: "amp-label" },
                "Subtitles"
              ),
              React.createElement("button", { className: "amp-icon amp-icon-right amp-right", tabIndex: "-1" }),
              React.createElement(
                "span",
                { className: "amp-right" },
                this.player.captioning.getHidden() ? "Off" : this.state.language
              )
            ),
            React.createElement(
              ListItem,
              { onClick: this.changeState.bind(this, 2) },
              React.createElement(
                "span",
                { className: "amp-label" },
                "Quality"
              ),
              React.createElement("button", { className: "amp-icon amp-icon-right amp-right", tabIndex: "-1" }),
              React.createElement(
                "span",
                { className: "amp-right" },
                this.state.bitrateLabel
              )
            ),
            React.createElement(
              ListItem,
              { onClick: this.changeState.bind(this, 3) },
              React.createElement(
                "span",
                { className: "amp-label" },
                "Speed"
              ),
              React.createElement("button", { className: "amp-icon amp-icon-right amp-right", tabIndex: "-1" }),
              React.createElement(
                "span",
                { className: "amp-right" },
                amp.getPlaybackRate() === 1 ? 'Normal' : amp.getPlaybackRate()
              )
            )
          );
          break;
        case 1:
          return React.createElement(
            "div",
            { ref: "element", className: "amp-captioning-settings amp-panel " + this.className },
            React.createElement(CaptionSettings, { ref: "firstElem", captionState: this.state.captioningSettingState, captionTracks: this.state.captioningTracks, gotoSettings: this.changeState.bind(this, 0) })
          );
          break;
        case 2:
          return React.createElement(
            "div",
            { ref: "element", className: "amp-bitrate amp-panel " + this.className },
            React.createElement(Bitrate, { ref: "firstElem", bitrate: this.state, gotoSettings: this.changeState.bind(this, 0) })
          );
          break;
        case 3:
          return React.createElement(
            "div",
            { ref: "element", className: "amp-playback-rate amp-panel " + this.className },
            React.createElement(PlaybackRate, { ref: "firstElem", playbackState: this.state.playbackSettingState, playbackrate: this.state, gotoSettings: this.changeState.bind(this, 0) })
          );
          break;
      }
    }
  }]);
  return Settings;
}(Panel);

var Share = function (_Panel) {
  babelHelpers.inherits(Share, _Panel);

  function Share(props, context) {
    babelHelpers.classCallCheck(this, Share);

    var _this = babelHelpers.possibleConstructorReturn(this, (Share.__proto__ || Object.getPrototypeOf(Share)).call(this, props, context));

    _this.listOptions = [{ label: "Facebook", icon: "amp-fb", url: "www.facebook.html" }, { label: "Twitter", icon: "amp-tw", url: "www.twitter.com" }, { label: "Email", icon: "amp-em", url: "" }, { label: "Embed", icon: "amp-eb", url: "" }];
    return _this;
  }

  babelHelpers.createClass(Share, [{
    key: "clickHandler",
    value: function clickHandler(object, index) {
      if (confirm("Would you like to share via:" + object.label) == true) {
        alert("You clicked to share");
      } else {
        alert("You did not share");
      }
    }
  }, {
    key: "render",
    value: function render() {

      var OptionsList = this.listOptions.map(function (object, index) {

        return React.createElement(
          "div",
          { key: index, className: "amp-list-item", onClick: this.clickHandler.bind(this, object, index) },
          React.createElement("button", { className: "amp-icon " + object.icon }),
          React.createElement(
            "span",
            null,
            object.label
          )
        );
      }, this);

      return React.createElement(
        "div",
        { ref: "element", className: "amp-share amp-panel " + this.className },
        OptionsList
      );
    }
  }]);
  return Share;
}(Panel);

var CaptionToggleButton = function (_Toggle) {
  babelHelpers.inherits(CaptionToggleButton, _Toggle);

  function CaptionToggleButton(props, context) {
    babelHelpers.classCallCheck(this, CaptionToggleButton);

    var _this = babelHelpers.possibleConstructorReturn(this, (CaptionToggleButton.__proto__ || Object.getPrototypeOf(CaptionToggleButton)).call(this, props, context));

    _this.classList.add("amp-cc");
    _this.state.altText = "MSG_CLOSED_CAPTIONING";
    _this.state.toggled = !_this.player.captioning.getHidden();
    return _this;
  }

  babelHelpers.createClass(CaptionToggleButton, [{
    key: "onChange",
    value: function onChange(event) {
      this.player.captioning.setHidden(!this.player.captioning.getHidden());
    }
  }]);
  return CaptionToggleButton;
}(Toggle);

var JumpBack = function (_Control) {
  babelHelpers.inherits(JumpBack, _Control);

  function JumpBack(props, context) {
    babelHelpers.classCallCheck(this, JumpBack);

    var _this = babelHelpers.possibleConstructorReturn(this, (JumpBack.__proto__ || Object.getPrototypeOf(JumpBack)).call(this, props, context));

    _this.classList.add("amp-jump-back");
    _this.state.altText = "MSG_JUMP_BACK";
    return _this;
  }

  babelHelpers.createClass(JumpBack, [{
    key: "onClick",
    value: function onClick() {
      var player = this.player;
      this.player.currentTime = Math.max(this.player.currentTime - 10, 0);
    }
  }]);
  return JumpBack;
}(Control);

var JumpForward = function (_Control) {
  babelHelpers.inherits(JumpForward, _Control);

  function JumpForward(props, context) {
    babelHelpers.classCallCheck(this, JumpForward);

    var _this = babelHelpers.possibleConstructorReturn(this, (JumpForward.__proto__ || Object.getPrototypeOf(JumpForward)).call(this, props, context));

    _this.classList.add("amp-jump-forward");
    _this.state.altText = "MSG_JUMP_AHEAD";
    return _this;
  }

  babelHelpers.createClass(JumpForward, [{
    key: "onClick",
    value: function onClick() {
      if (!this.player.getEnded()) {
        this.player.currentTime = Math.min(this.player.currentTime + 10, this.player.getDuration() - 1);
      }
    }
  }]);
  return JumpForward;
}(Control);

var Poster = function (_Component) {
  babelHelpers.inherits(Poster, _Component);

  function Poster() {
    babelHelpers.classCallCheck(this, Poster);
    return babelHelpers.possibleConstructorReturn(this, (Poster.__proto__ || Object.getPrototypeOf(Poster)).apply(this, arguments));
  }

  babelHelpers.createClass(Poster, [{
    key: "onmediachange",
    value: function onmediachange(event) {
      this.setState({ src: this.player.media.poster });
    }
  }, {
    key: "render",
    value: function render() {
      return React.createElement("img", { className: "amp-poster", src: this.state.src });
    }
  }]);
  return Poster;
}(Component);

var Title = function (_Component) {
  babelHelpers.inherits(Title, _Component);

  function Title(props, context) {
    babelHelpers.classCallCheck(this, Title);

    var _this = babelHelpers.possibleConstructorReturn(this, (Title.__proto__ || Object.getPrototypeOf(Title)).call(this, props, context));

    _this.classList.add("amp-title");
    return _this;
  }

  babelHelpers.createClass(Title, [{
    key: "onmediachange",
    value: function onmediachange(event) {
      this.setState({ textContent: this.player.media.title });
    }
  }]);
  return Title;
}(Component);

var ErrorMsg = function (_Component) {
  babelHelpers.inherits(ErrorMsg, _Component);

  function ErrorMsg() {
    babelHelpers.classCallCheck(this, ErrorMsg);
    return babelHelpers.possibleConstructorReturn(this, (ErrorMsg.__proto__ || Object.getPrototypeOf(ErrorMsg)).apply(this, arguments));
  }

  babelHelpers.createClass(ErrorMsg, [{
    key: "onerror",
    value: function onerror(event) {
      this.setState({ error: event.detail.message });
    }
  }, {
    key: "render",
    value: function render() {
      return React.createElement(
        "div",
        { className: "amp-error-msg" },
        React.createElement(
          "div",
          null,
          this.state.error
        )
      );
    }
  }]);
  return ErrorMsg;
}(Component);

var ContextMenu = function (_Component) {
  babelHelpers.inherits(ContextMenu, _Component);

  function ContextMenu(props, context) {
    babelHelpers.classCallCheck(this, ContextMenu);
    return babelHelpers.possibleConstructorReturn(this, (ContextMenu.__proto__ || Object.getPrototypeOf(ContextMenu)).call(this, props, context));
  }

  babelHelpers.createClass(ContextMenu, [{
    key: "render",
    value: function render() {
      var menuItems = [React.createElement(
        "li",
        { className: "amp-context-item", key: "0" },
        this.player.version
      )];

      if (typeof akamaiGetViewerId == "function") menuItems.push(React.createElement(
        "li",
        { className: "amp-context-item amp-selectable", key: "1" },
        "akamaiGetViewerId()"
      ));

      var style = {
        top: this.props.y + "px",
        left: this.props.x + "px"
      };

      return React.createElement(
        "ul",
        { ref: "element", className: "amp-context-menu", style: style },
        menuItems
      );
    }
  }]);
  return ContextMenu;
}(Component);

var Ads = function (_Component) {
  babelHelpers.inherits(Ads, _Component);

  function Ads(props, context) {
    babelHelpers.classCallCheck(this, Ads);

    var _this = babelHelpers.possibleConstructorReturn(this, (Ads.__proto__ || Object.getPrototypeOf(Ads)).call(this, props, context));

    _this.classList.add("amp-ads");
    _this.state.count = 0;
    _this.state.total = 0;
    _this.state.time = Utils.formatTimecode(0);

    var ads = _this.player.ads;
    ads.addEventListener("breakstart", _this.onadbreakstart.bind(_this));
    ads.addEventListener("breakend", _this.onadbreakend.bind(_this));
    ads.addEventListener("loaded", _this.onadloaded.bind(_this));
    ads.addEventListener("timeremaining", _this.onadtimeremaining.bind(_this));
    return _this;
  }

  babelHelpers.createClass(Ads, [{
    key: "onadbreakstart",
    value: function onadbreakstart(event) {
      var adVO = event.detail;
      this.setState({ position: 1, total: adVO.totalAds });
      this.plugin.container.classList.update({ "amp-ad-break": true });
    }
  }, {
    key: "onadbreakend",
    value: function onadbreakend(event) {
      this.plugin.container.classList.update({ "amp-ad-break": false });
    }
  }, {
    key: "onadloaded",
    value: function onadloaded(event) {
      var adVO = event.detail;
      this.setState({ position: adVO.position, time: adVO.duration });
    }
  }, {
    key: "onadtimeremaining",
    value: function onadtimeremaining(event) {
      this.setState({ time: event.detail });
    }
  }, {
    key: "render",
    value: function render() {
      return React.createElement(
        "div",
        { className: "amp-ads" },
        React.createElement(
          "div",
          { className: "amp-bar amp-ad-info" },
          React.createElement(
            "div",
            { ref: "count", className: "amp-ad-component amp-ad-count" },
            this.l10n.MSG_AD + " " + this.state.position + " " + this.l10n.MSG_OF + " " + this.state.total
          ),
          React.createElement("div", { ref: "spacerLeft", className: "amp-spacer" }),
          React.createElement("div", { ref: "spacerRight", className: "amp-spacer" }),
          React.createElement(
            "div",
            { ref: "time", className: "amp-ad-component amp-ad-time" },
            Utils.formatTimecode(Math.round(this.state.time))
          )
        )
      );
    }
  }]);
  return Ads;
}(Component);

var UI = function (_Component) {
  babelHelpers.inherits(UI, _Component);

  function UI(props) {
    babelHelpers.classCallCheck(this, UI);

    var _this = babelHelpers.possibleConstructorReturn(this, (UI.__proto__ || Object.getPrototypeOf(UI)).call(this, props));

    _this.state.playState = "ready";
    _this.isTouchDevice = akamai.amp.utils.Utils.isTouch;
    _this.isVolumeSettable = akamai.amp.utils.Utils.isVolumeSettable();
    _this.contextMenuClick = _this.contextMenuClick.bind(_this);
    _this.timeout = null;
    return _this;
  }

  babelHelpers.createClass(UI, [{
    key: "getChildContext",
    value: function getChildContext() {
      return {
        player: this.props.player,
        config: this.props.player,
        plugin: this
      };
    }
  }, {
    key: "onready",
    value: function onready(event) {
      this.container.classList.update({ "amp-cc-active": !this.player.captioning.getHidden() });
      this.player.captioning.addEventListener("visibilitychange", this.onvisibilitychange.bind(this));
    }
  }, {
    key: "onvisibilitychange",
    value: function onvisibilitychange(event) {
      this.container.classList.update({ "amp-cc-active": event.detail });
    }
  }, {
    key: "onmediachange",
    value: function onmediachange(event) {
      var media = this.player.media;
      this.container.classList.update({ "amp-text-tracks": media.tracks && media.tracks.length });
      this.player.container.classList.remove("akamai-active");
    }
  }, {
    key: "onfullscreenchange",
    value: function onfullscreenchange(event) {
      this.container.classList.update({ "amp-full-screen": event.detail });
    }
  }, {
    key: "onplaystatechange",
    value: function onplaystatechange(event) {
      var _updates;

      var updates = (_updates = {}, babelHelpers.defineProperty(_updates, "amp-waiting", false), babelHelpers.defineProperty(_updates, "amp-" + event.detail.previous, false), babelHelpers.defineProperty(_updates, "amp-" + event.detail.value, true), _updates);
      this.container.classList.update(updates);
    }
  }, {
    key: "onplaying",
    value: function onplaying(event) {
      this.container.classList.remove("amp-waiting");

      if (!this.isTouchDevice) return;

      this.activeState = "none";
    }
  }, {
    key: "onwaiting",
    value: function onwaiting(event) {
      this.container.classList.add("amp-waiting");
    }
  }, {
    key: "onseeked",
    value: function onseeked(event) {
      this.container.classList.remove("amp-waiting");
    }
  }, {
    key: "onerror",
    value: function onerror(event) {
      this.container.classList.add("amp-error");
    }
  }, {
    key: "onislive",
    value: function onislive(event) {
      this.container.classList.update({ "amp-is-live": event.detail });
    }
  }, {
    key: "ontemporaltypechange",
    value: function ontemporaltypechange(event) {
      var _updates2;

      var updates = (_updates2 = {}, babelHelpers.defineProperty(_updates2, "amp-" + event.detail.previous, false), babelHelpers.defineProperty(_updates2, "amp-" + event.detail.value, true), _updates2);
      this.container.classList.update(updates);
    }
  }, {
    key: "togglePlayPause",
    value: function togglePlayPause() {
      if (this.player.paused) {
        this.player.play();
      } else {
        this.player.pause();
      }
    }
  }, {
    key: "onMouseEnter",
    value: function onMouseEnter(event) {
      clearTimeout(this.timeout);
      this.activeState = "active";
    }
  }, {
    key: "onMouseLeave",
    value: function onMouseLeave(event) {
      var _this2 = this;

      this.activeState = "inactive";
      this.timeout = setTimeout(function () {
        _this2.activeState = "none";
      }, this.config.autoHide * 1000);
    }
  }, {
    key: "onClick",
    value: function onClick() {
      if (this.isTouchDevice) {
        if (this.activeState == "active") this.activeState = "none";else this.activeState = "active";
      } else this.togglePlayPause();
    }
  }, {
    key: "isFocused",
    value: function isFocused(element) {
      var container = this.container.element;
      return element == container || container.contains(element);
    }
  }, {
    key: "onFocus",
    value: function onFocus(event) {
      var focused = this.isFocused(event.target);
      this.focused = event.target.nodeName != "BUTTON" && focused;
      if (focused) this.player.container.classList.add("amp-active");
    }
  }, {
    key: "onBlur",
    value: function onBlur(event) {
      var focused = this.isFocused(event.target);
      this.focused = event.target.nodeName != "BUTTON" && focused;
      if (!focused) this.onMouseLeave(event);
    }
  }, {
    key: "onKeyDown",
    value: function onKeyDown(event) {
      switch (event.keyCode) {
        case 77:
          // M
          amp.muted = !amp.muted;
          break;

        case 67:
          // C
          amp.captioning.setHidden(!amp.captioning.getHidden());
          break;

        case 70:
          // F
          amp.displayState == amp.displayState == 'full-screen' ? amp.exitFullScreen() : amp.enterFullScreen();
          break;

        case 13: // Enter
        case 32:
          // Space
          if (this.focused === true) this.togglePlayPause();
          break;
      }

      if (this.focused == false) return;

      switch (event.keyCode) {
        case 13: // Enter
        case 32:
          // Space
          this.togglePlayPause();
          break;

        case 39: // Left
        case 37:
          // Right
          this.refs.progress.onKeyDown(event);
          break;

        case 38: // Up
        case 40:
          // Down
          this.refs.volume.onKeyDown(event);
          break;
      }
    }
  }, {
    key: "contextMenuClick",
    value: function contextMenuClick(event) {
      if (/selectable/.test(event.target.className)) return false;
      this.removeContextMenu(event);
      return false;
    }
  }, {
    key: "removeContextMenu",
    value: function removeContextMenu(event) {
      document.body.removeEventListener("click", this.contextMenuClick);
      var parent = this.player.container.parentNode;
      parent.removeChild(this.contextMenu);
      this.contextMenu = null;
    }
  }, {
    key: "onContextMenu",
    value: function onContextMenu(event) {
      if (this.player.config.debug === true) return;

      event.preventDefault();

      var parent = this.player.container.parentNode;
      var contextMenu = React.createElement(ContextMenu, { player: this.player, x: event.pageX, y: event.pageY });

      if (this.contextMenu != null) this.removeContextMenu();

      this.contextMenu = document.createElement("div");
      parent.appendChild(this.contextMenu);
      document.body.addEventListener("click", this.contextMenuClick);
      ReactDOM.render(contextMenu, this.contextMenu);
    }
  }, {
    key: "replay",
    value: function replay() {
      this.player.replay();
      setTimeout(this.player.play.bind(this.player), 150);
    }
  }, {
    key: "render",
    value: function render() {
      var _this3 = this;

      return React.createElement(
        Container,
        { ref: "container", classList: ["amp-react", "amp-ui", "amp-ready", "amp-active"],
          onMouseEnter: function onMouseEnter(event) {
            return _this3.onMouseEnter(event);
          },
          onMouseLeave: function onMouseLeave(event) {
            return _this3.onMouseLeave(event);
          },
          onFocus: function onFocus(event) {
            return _this3.onFocus(event);
          },
          onBlur: function onBlur(event) {
            return _this3.onBlur(event);
          },
          onKeyDown: function onKeyDown(event) {
            return _this3.onKeyDown(event);
          },
          onContextMenu: function onContextMenu(event) {
            return _this3.onContextMenu(event);
          },
          tabIndex: "0" },
        React.createElement("div", { className: "amp-interactive", onClick: function onClick(event) {
            return _this3.onClick(event);
          } }),
        React.createElement(Poster, { ref: "poster" }),
        React.createElement(Title, { ref: "title" }),
        this.player.ads != null && React.createElement(Ads, { ref: "ads" }),
        React.createElement(PauseOverlay, { ref: "pauseOverlay" }),
        React.createElement(BufferingOverlay, { ref: "bufferingOverlay" }),
        React.createElement(Progress, { ref: "progress" }),
        React.createElement(
          Container,
          { ref: "controls", className: "amp-bar amp-controls" },
          React.createElement(PlayPause, { ref: "playpause" }),
          React.createElement(JumpBack, { ref: "jumpback" }),
          React.createElement(JumpForward, { ref: "jumpforward" }),
          React.createElement(
            "div",
            { ref: "timeDisplay", className: "amp-time-display" },
            React.createElement(CurrentTime, { ref: "currentTime" }),
            React.createElement("span", { ref: "timeSeparator", className: "amp-time-separator" }),
            React.createElement(Duration, { ref: "duration" }),
            React.createElement(
              "span",
              { className: "amp-live-label" },
              "Live"
            )
          ),
          this.isVolumeSettable && React.createElement(Mute, { ref: "mute" }),
          this.isVolumeSettable && React.createElement(Volume, { ref: "volume" }),
          React.createElement("div", { ref: "spacerLeft", className: "amp-spacer" }),
          React.createElement("div", { ref: "spacerRight", className: "amp-spacer" }),
          this.player.share != null && React.createElement(PanelControl, { ref: "share", altText: "MSG_SHARE", className: "amp-share", onClick: function onClick() {
              return _this3.refs.sharePanel.toggle();
            } }),
          React.createElement(CaptionToggleButton, { ref: "cc" }),
          React.createElement(PanelControl, { ref: "settings", altText: "MSG_SETTINGS", className: "amp-settings",
            onClick: function onClick(event) {
              return _this3.refs.settingsPanel.toggle(event);
            },
            onKeyDown: function onKeyDown(event) {
              return _this3.refs.settingsPanel.onKeyDown(event);
            } }),
          React.createElement(Fullscreen, { ref: "fullscreen" })
        ),
        this.player.share != null && React.createElement(Share, { ref: "sharePanel" }),
        React.createElement(Settings, { ref: "settingsPanel" }),
        React.createElement(ErrorMsg, { ref: "error" }),
        this.state.contextMenu
      );
    }
  }, {
    key: "destroy",
    value: function destroy() {
      ReactDOM.unmountComponentAtNode(this._container);
    }
  }, {
    key: "container",
    get: function get() {
      return this.refs.container;
    }
  }, {
    key: "components",
    get: function get() {
      return this.refs;
    }
  }, {
    key: "mode",
    get: function get() {
      return this.state.mode;
    },
    set: function set(value) {
      var _container$classList$;

      var mode = this.state.mode;
      this.container.classList.update((_container$classList$ = {}, babelHelpers.defineProperty(_container$classList$, "amp-controls-" + mode, false), babelHelpers.defineProperty(_container$classList$, "amp-controls-" + value, true), _container$classList$));
      this.player.container.classList.remove("amp-controls-" + mode);
      this.player.container.classList.add("amp-controls-" + value);
      this.setState({ mode: value });
    }
  }, {
    key: "activeState",
    set: function set(value) {
      var active = value == "active";
      var inactive = value == "inactive";
      this.container.classList.update({ "amp-active": active, "amp-inactive": inactive });

      if (active === true) {
        this.player.container.classList.add("amp-active");
      } else {
        this.player.container.classList.remove("amp-active");
      }

      if (inactive === true) {
        this.player.container.classList.add("amp-inactive");
      } else {
        this.player.container.classList.remove("amp-inactive");
      }
    },
    get: function get() {
      switch (true) {
        case this.container.classList.contains("amp-active"):
          return "active";

        case this.container.classList.contains("amp-inactive"):
          return "inactive";

        default:
          return "none";
      }
    }
  }], [{
    key: "create",
    value: function create(player, config) {
      return new Promise(function (resolve, reject) {
        player.once("ready", function () {
          if (player.mediaElement.setPlayerProperty != null) player.mediaElement.setPlayerProperty("controlsMode", "none");

          var element = document.querySelector(".amp-react");
          player.container.removeChild(element);
          player.container.appendChild(element);
        });
        resolve(ReactDOM.render(React.createElement(UI, { player: player, config: config }), player.container));
      });
    }
  }, {
    key: "childContextTypes",
    get: function get() {
      return {
        player: React.PropTypes.object,
        config: React.PropTypes.object,
        plugin: React.PropTypes.object
      };
    }
  }]);
  return UI;
}(Component);

akamai.amp.AMP.registerPlugin("react", UI.create);

exports.UI = UI;
exports.Component = Component;
exports.Container = Container;
exports.ClassList = ClassList;

}((this.akamai.amp.react = this.akamai.amp.react || {})));
